#!/usr/bin/env python2

from . import runtests
runtests.setup()
